#!/usr/bin/env python

from distutils.core import setup

setup(name='lolcat',
      version='0.43.0',
      description='Rainbows and unicorns!',
      author='Wijnand Modderman-Lenstra',
      author_email='maze@pyth0n.org',
      url='https://github.com/tehmaze/lolcat/',
      scripts=['lolcat'],
     )
